
#ifndef _C11_sh525_
#define _C11_sh525_

#ifdef __cplusplus
extern "C" {
#endif

static EIF_REFERENCE F577_10089_body(EIF_REFERENCE);
extern EIF_REFERENCE F577_10089(EIF_REFERENCE);
extern void EIF_Minit525(void);
extern void F4745_59456(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
